


## 📖 About
# * **🤔💭What is SoftwareAI?**
* SoftwareAI is an AI framework with the aim of creating a software/application development company/organization governed by AI, its purpose is not only to create the software with updates, landing page, technical and github documentation, schedules and spreadsheets, SoftwareAI is able to govern a software company completely with a CEO team, accounting team, support team, and all the teams that make up a software company
#
# * **💭How did SoftwareAI come about?**
Thu, July 18th at 4:17 pm OPENAI launched the GPT-4o mini, 60% cheaper than other models... This made my big project viable, a software organization/company formed by artificial intelligence, all the code will be open and free interpretation, however business applications created with Qt5 from SoftwareAI will be sold and made available at site
#
# * **💭What is SoftwareAI capable of?**
* in version 0.1.7, SoftwareAI is capable of creating software with a pre-project document, project roadmap, schedule, spreadsheet, requirement analysis, in addition to creating the software repository on github with the code, README.MD and description in addition to implementing 1 improvement through commit, in version 0.1 all teams that make up the organization have communication limited to importing python, there is still no intercommunication between teams
* Watch the potential of SoftwareAI's Unbuildable Beta V 0.1.7 at 
    ### Beta v0.1.8 (Current)
    Demonstration Projects:
    - [💹 Solana Analyzer](https://github.com/A-I-O-R-G/solana-analyzer)
    - [🎵 Music Recommendation System](https://github.com/A-I-O-R-G/music-recommendation-system)
    - [📝 YouTube Tutorial Transcription](https://github.com/A-I-O-R-G/transcricao-tutorial-youtube)
    - [📊 CSV Data Analyzer](https://github.com/A-I-O-R-G/CSVDataAnalyzer)
    - [📚 Course Description Generator](https://github.com/A-I-O-R-G/GeradorDeDescricaoDeCursos)

    ### Beta v0.1.7 (Previous)
    Demonstration Projects:
    - [📺 Twitch VOD Downloader](https://github.com/A-I-O-R-G/Twitch-VOD-Downloader)
    - [📄 PDFGenPython](https://github.com/A-I-O-R-G/PDFGenPython)
    - [📁 OrganizaArquivos](https://github.com/A-I-O-R-G/OrganizaArquivos)
    - [💱 ConversorMoedasAPI](https://github.com/A-I-O-R-G/ConversorMoedasAPI)





